@@ -26,19 +26,31 @@ class CommentMixin:
             A list of objects of Comment
         """
         # TODO: to public or private
-        media_id = self.media_id(media_id)
-        max_id = None
-        comments = []
-        while True:
-            try:
-                result = self.private_request(
-                    f"media/{media_id}/comments/", params={"max_id": max_id}
-                )
-                for comment in result["comments"]:
+        def get_comments():
+            if result.get("comments"):
+                for comment in result.get("comments"):
                     comments.append(extract_comment(comment))
-                if not result["has_more_comments"]:
+        media_id = self.media_id(media_id)
+        params = None
+        comments = []
+        result = self.private_request(
+            f"media/{media_id}/comments/", params
+        )
+        get_comments()
+        while ((result.get("has_more_comments") and result.get("next_max_id"))
+               or (result.get("has_more_headload_comments") and result.get("next_min_id"))):
+            try:
+                if result.get("has_more_comments"):
+                    params = {"max_id": result.get("next_max_id")}
+                else:
+                    params = {"min_id": result.get("next_min_id")}
+                if not (result.get("next_max_id") or result.get("next_min_id")
+                        or result.get("comments")):
                     break
-                max_id = result["next_max_id"]
+                result = self.private_request(
+                    f"media/{media_id}/comments/", params
+                )
+                get_comments()
             except ClientNotFoundError as e:
                 raise MediaNotFound(e, media_id=media_id, **self.last_json)
             except ClientError as e:
